@@ -1,10 +1,10 @@
 /*
- * Logswan 2.1.12
- * Copyright (c) 2015-2021, Frederic Cambus
+ * Logswan 2.1.14
+ * Copyright (c) 2015-2023, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2021-11-16
+ * Last Updated: 2023-03-13
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
@@ -44,13 +44,13 @@
 #include "parse.h"
 
 static void
-usage()
+usage(void)
 {
-	printf("logswan [-ghv] [-d db] logfile\n\n" \
-	    "The options are as follows:\n\n" \
-	    "	-d db	Specify path to a GeoIP database.\n" \
-	    "	-g	Enable GeoIP lookups.\n" \
-	    "	-h	Display usage.\n" \
+	printf("logswan [-ghv] [-d db] logfile\n\n"
+	    "The options are as follows:\n\n"
+	    "	-d db	Specify path to a GeoIP database.\n"
+	    "	-g	Enable GeoIP lookups.\n"
+	    "	-h	Display usage.\n"
 	    "	-v	Display version.\n");
 }
 
